@@ -29,7 +29,7 @@ if [ "$BTRFS_SCRUB_PRIORITY" = "normal" ]; then
 fi
 
 {
-evaluate_auto_mountpoint BTRFS_SCRUB_MOUNTPOINTS
+BTRFS_SCRUB_MOUNTPOINTS=$(expand_auto_mountpoint "$BTRFS_SCRUB_MOUNTPOINTS")
 OIFS="$IFS"
 IFS=:
 exec 2>&1 # redirect stderr to stdout to catch all output to log destination
