@@ -18,7 +18,7 @@ LOGIDENTIFIER='btrfs-trim'
 . $(dirname $(realpath "$0"))/btrfsmaintenance-functions
 
 {
-evaluate_auto_mountpoint BTRFS_TRIM_MOUNTPOINTS
+BTRFS_TRIM_MOUNTPOINTS=$(expand_auto_mountpoint "$BTRFS_TRIM_MOUNTPOINTS")
 OIFS="$IFS"
 IFS=:
 exec 2>&1 # redirect stderr to stdout to catch all output to log destination
@@ -29,7 +29,7 @@ for MNT in $BTRFS_TRIM_MOUNTPOINTS; do
 		continue
 	fi
 	echo "Running fstrim on $MNT"
-	fstrim "$MNT"
+	fstrim --verbose "$MNT"
 done
 
 } | \
